@@ -1,27 +1,27 @@
 <?php
-// $Horde: turba/lib/ListView.php,v 1.8.2.2 2002/04/12 16:10:07 jan Exp $
-
 /**
  * The Turba_ListView:: class provides an interface for objects that
  * visualize Turba_lists.
  *
+ * $Horde: turba/lib/ListView.php,v 1.17 2004/04/01 21:23:37 chuck Exp $
+ *
  * @author  Chuck Hagenbuch <chuck@horde.org>
  * @author  Jon Parise <jon@csh.rit.edu>
- * @version $Revision: 1.8.2.2 $
+ * @version $Revision: 1.17 $
  * @since   Turba 0.0.1
- * @package turba
+ * @package Turba
  */
 class Turba_ListView {
 
     /**
      * The Turba_List object that we are visualizing.
-     * @var Turba_List
+     * @var object Turba_List $list
      */
     var $list;
 
     /**
      * The template used to display each row of the list.
-     * @var string
+     * @var string $template
      */
     var $template;
 
@@ -39,18 +39,45 @@ class Turba_ListView {
 
     /**
      * Renders the list contents into an HTML view.
+     *
+     * @return integer $count The number of objects in the list.
      */
-    function display()
+    function display($min, $max)
     {
-        include TURBA_BASE . '/config/html.php';
         $i = 0;
         $this->list->reset();
+
         while ($ob = $this->list->next()) {
+            if ($i++ < $min || $i > $max) {
+                continue;
+            }
+
             include $this->template;
-            $i++;
         }
         return $i;
     }
 
+    /**
+     * Renders the list contents that match $alpha into and HTML view.
+     *
+     * @param $alpha    The letter to display.
+     */
+    function displayAlpha($alpha)
+    {
+        $this->list->reset();
+        $alpha = String::lower($alpha);
+
+        $i = 0;
+        while ($ob = $this->list->next()) {
+            $name = Turba::formatName($ob);
+
+            if ($alpha != '*' && String::lower($name{0}) != $alpha) {
+                continue;
+            }
+
+            include $this->template;
+            $i++;
+        }
+    }
+
 }
-?>
