@@ -1,16 +1,16 @@
 <?php
-// $Horde: turba/lib/ListView/Rolodex.php,v 1.7.2.1 2002/04/12 16:10:11 jan Exp $
+// $Horde: turba/lib/ListView/Rolodex.php,v 1.10 2004/05/20 16:39:08 jan Exp $
 
-require_once './lib/ListView.php';
+require_once TURBA_BASE . '/lib/ListView.php';
 
 /**
  * The Turba_ListView_Rolodex:: class provides a set of methods for
  * visualizing a Turba_list as a rolodex.
  *
  * @author   Chuck Hagenbuch <chuck@horde.org>
- * @version  $Revision: 1.7.2.1 $
+ * @version  $Revision: 1.10 $
  * @since Turba 0.0.1
- * @package turba
+ * @package Turba
  */
 class Turba_ListView_Rolodex extends Turba_ListView {
 
